@@ -36,9 +36,7 @@ class WhatsappAPI():
         userprof = os.environ['USERPROFILE']
 
         if browser.lower() == 'firefox':
-            profile = webdriver.FirefoxProfile(f'{userprof}/AppData/Roaming/Mozilla/Firefox/Profiles/931td2o2.default-release')
-            print(userprof)
-            self.driver = webdriver.Firefox(firefox_profile=profile)
+            self.driver = webdriver.Firefox()
             self.driver.get('https://web.whatsapp.com')
 
         if browser.lower() == 'chrome':
